@@ -1,4 +1,4 @@
-# vim:set et sts=4 sw=4
+# vim:et sts=4 sw=4
 #
 # ibus-table - The Tables engine for IBus
 #
@@ -81,6 +81,7 @@ class IMApp:
         self.__bus = ibus.Bus()
         self.__bus.connect("disconnected", self.__bus_destroy_cb)
         self.__factory = factory.EngineFactory(self.__bus, dbfile)
+        self.destroied = False
         if exec_by_ibus:
             self.__bus.request_name("org.freedesktop.IBus.Table", 0)
         else:
@@ -116,16 +117,20 @@ class IMApp:
 
     def run(self):
         self.__mainloop.run()
+        self.__bus_destroy_cb()
 
     def quit(self):
         self.__bus_destroy_cb()
 
     def __bus_destroy_cb(self, bus=None):
+        if self.destroied:
+            return
+        print "finalizing:)"
         self.__factory.do_destroy()
+        self.destroied = True
         self.__mainloop.quit()
 
 def cleanup (ima_ins):
-    print "cleanup"
     ima_ins.quit()
     sys.exit()
 
@@ -154,8 +159,8 @@ def main():
         #    Elements
         dbs = os.listdir(db_dir)
         dbs = filter (lambda x: x.endswith('.db'), dbs)
-        if not dbs:
-            return
+        #if not dbs:
+        #    return
 
         egs = Element('engines')
         for _db in dbs:
@@ -166,9 +171,13 @@ def main():
             _name.text = _db.replace ('.db','')
             
             _longname = SubElement (_engine, 'longname')
-            _locale = getdefaultlocale()[0].lower()
-            _longname.text = _sq_db.get_ime_property ( \
+            _longname.text = ''
+            try:
+                _locale = getdefaultlocale()[0].lower()
+                _longname.text = _sq_db.get_ime_property ( \
                     '.'.join(['name',_locale]) )
+            except:
+                pass
             if not _longname.text:
                 _longname.text = _name.text
             
